@@ -1,5 +1,4 @@
 # pylint: disable=unused-argument,invalid-name,line-too-long
-from __future__ import annotations
 
 from typing import List
 
@@ -21,7 +20,7 @@ class PGView(ReplaceableEntity):
     """
 
     @classmethod
-    def from_sql(cls, sql: str) -> PGView:
+    def from_sql(cls, sql: str) -> "PGView":
         """Create an instance from a SQL string"""
         template = "create{}view{:s}{schema}.{signature}{:s}as{:s}{definition}"
         result = parse(template, sql, case_sensitive=False)
@@ -54,7 +53,7 @@ class PGView(ReplaceableEntity):
         )
 
     @classmethod
-    def from_database(cls, connection, schema) -> List[PGView]:
+    def from_database(cls, connection, schema) -> List["PGView"]:
         """Get a list of all functions defined in the db"""
         sql = sql_text(
             f"""
